==> cvxopt_1.0.orig.tar.gz: cvxopt-1.0/src/C/blas_redefines.h <==
#ifdef BLAS_NO_UNDERSCORE

#define dswap_ dswap
#define zswap_ zswap
#define dscal_ dscal
#define zscal_ zscal
#define zdscal_ zdscal
#define dcopy_ dcopy
#define zcopy_ zcopy
#define daxpy_ daxpy
#define zaxpy_ zaxpy
#define ddot_ ddot
#define dnrm2_ dnrm2
#define dznrm2_ dznrm2
#define dasum_ dasum
#define dzasum_ dzasum
#define idamax_ idamax
#define izamax_ izamax
#define dgemv_ dgemv
#define zgemv_ zgemv
#define dgbmv_ dgbmv
#define zgbmv_ zgbmv
#define dsymv_ dsymv
#define zsymv_ zsymv
#define zhemv_ zhemv
#define dsbmv_ dsbmv
#define zhbmv_ zhbmv
#define dtrmv_ dtrmv
#define ztrmv_ ztrmv
#define dtbmv_ dtbmv
#define ztbmv_ ztbmv
#define dtrsv_ dtrsv
#define ztrsv_ ztrsv
#define dtbsv_ dtbsv
#define ztbsv_ ztbsv
#define dger_ dger
#define zgerc_ zgerc
#define zgeru_ zgeru
#define dsyr_ dsyr
#define zher_ zher
#define dsyr2_ dsyr2
#define zher2_ zher2
#define dgemm_ dgemm
#define zgemm_ zgemm
#define dsymm_ dsymm
#define zsymm_ zsymm
#define zhemm_ zhemm
#define dsyrk_ dsyrk
#define zsyrk_ zsyrk
#define zherk_ zherk
#define dsyr2k_ dsyr2k
#define zsyr2k_ zsyr2k
#define zher2k_ zher2k
#define dtrmm_ dtrmm
#define ztrmm_ ztrmm
#define dtrsm_ dtrsm
#define ztrsm_ ztrsm
#define dgetrf_ dgetrf
#define zgetrf_ zgetrf
#define dgetrs_ dgetrs
#define zgetrs_ zgetrs
#define dgetri_ dgetri
#define zgetri_ zgetri
#define dgesv_ dgesv
#define zgesv_ zgesv
#define dpotrf_ dpotrf
#define dpotri_ dpotri
#define zpotri_ zpotri
#define zpotrf_ zpotrf
#define dpotrs_ dpotrs
#define zpotrs_ zpotrs
#define dposv_ dposv
#define zposv_ zposv
#define dsytrf_ dsytrf
#define zsytrf_ zsytrf
#define zhetrf_ zhetrf
#define dsytri_ dsytri
#define zsytri_ zsytri
#define dsytrs_ dsytrs
#define zsytrs_ zsytrs
#define zhetrs_ zhetrs
#define zhetri_ zhetri
#define dsysv_ dsysv
#define zsysv_ zsysv
#define dsygv_ dsygv
#define zhesv_ zhesv
#define dgels_ dgels
#define zgels_ zgels
#define dsyev_ dsyev
#define zheev_ zheev
#define dsyevx_ dsyevx
#define zheevx_ zheevx
#define dsyevd_ dsyevd
#define zheevd_ zheevd
#define dsyevr_ dsyevr
#define zheevr_ zheevr
#define ilaenv_ ilaenv
#define zhegv_ zhegv
#define dgesvd_ dgesvd
#define zgesvd_ zgesvd
#define dgesdd_ dgesdd
#define zgesdd_ zgesdd
#define dgeqrf_ dgeqrf
#define zgeqrf_ zgeqrf
#define dormqr_ dormqr
#define zunmqr_ zunmqr
#define dtrtrs_ dtrtrs
#define ztrtrs_ ztrtrs
#define dgbtrf_ dgbtrf
#define zgbtrf_ zgbtrf
#define dgbtrs_ dgbtrs
#define zgbtrs_ zgbtrs
#define dgbsv_  dgbsv
#define zgbsv_  zgbsv
#define dgtsv_  dgtsv
#define zgtsv_  zgtsv
#define dpbsv_  dpbsv
#define zpbsv_  zpbsv
#define dptsv_  dptsv
#define zptsv_  zptsv
#define dgttrf_ dgttrf
#define zgttrf_ zgttrf
#define dgttrs_ dgttrs
#define zgttrs_ zgttrs
#define dtrtri_ dtrtri
#define ztrtri_ ztrtri
#define dpbtrf_ dpbtrf
#define zpbtrf_ zpbtrf
#define dtbtrs_ dtbtrs
#define ztbtrs_ ztbtrs
#define dtbtrf_ dtbtrf
#define ztbtrf_ ztbtrf
#define dpttrf_ dpttrf
#define zpttrf_ zpttrf
#define dpbtrs_ dpbtrs
#define zpbtrs_ zpbtrs
#define dpttrs_ dpttrs
#define zpttrs_ zpttrs

#endif

==> cvxopt_1.1.orig.tar.gz: cvxopt-1.1/src/C/blas_redefines.h <==
#ifdef BLAS_NO_UNDERSCORE

#define dswap_ dswap
#define zswap_ zswap
#define dscal_ dscal
#define zscal_ zscal
#define zdscal_ zdscal
#define dcopy_ dcopy
#define zcopy_ zcopy
#define daxpy_ daxpy
#define zaxpy_ zaxpy
#define ddot_ ddot
#define dnrm2_ dnrm2
#define dznrm2_ dznrm2
#define dasum_ dasum
#define dzasum_ dzasum
#define idamax_ idamax
#define izamax_ izamax
#define dgemv_ dgemv
#define zgemv_ zgemv
#define dgbmv_ dgbmv
#define zgbmv_ zgbmv
#define dsymv_ dsymv
#define zsymv_ zsymv
#define zhemv_ zhemv
#define dsbmv_ dsbmv
#define zhbmv_ zhbmv
#define dtrmv_ dtrmv
#define ztrmv_ ztrmv
#define dtbmv_ dtbmv
#define ztbmv_ ztbmv
#define dtrsv_ dtrsv
#define ztrsv_ ztrsv
#define dtbsv_ dtbsv
#define ztbsv_ ztbsv
#define dger_ dger
#define zgerc_ zgerc
#define zgeru_ zgeru
#define dsyr_ dsyr
#define zher_ zher
#define dsyr2_ dsyr2
#define zher2_ zher2
#define dgemm_ dgemm
#define zgemm_ zgemm
#define dsymm_ dsymm
#define zsymm_ zsymm
#define zhemm_ zhemm
#define dsyrk_ dsyrk
#define zsyrk_ zsyrk
#define zherk_ zherk
#define dsyr2k_ dsyr2k
#define zsyr2k_ zsyr2k
#define zher2k_ zher2k
#define dtrmm_ dtrmm
#define ztrmm_ ztrmm
#define dtrsm_ dtrsm
#define ztrsm_ ztrsm
#define dgetrf_ dgetrf
#define zgetrf_ zgetrf
#define dgetrs_ dgetrs
#define zgetrs_ zgetrs
#define dgetri_ dgetri
#define zgetri_ zgetri
#define dgesv_ dgesv
#define zgesv_ zgesv
#define dpotrf_ dpotrf
#define dpotri_ dpotri
#define zpotri_ zpotri
#define zpotrf_ zpotrf
#define dpotrs_ dpotrs
#define zpotrs_ zpotrs
#define dposv_ dposv
#define zposv_ zposv
#define dsytrf_ dsytrf
#define zsytrf_ zsytrf
#define zhetrf_ zhetrf
#define dsytri_ dsytri
#define zsytri_ zsytri
#define dsytrs_ dsytrs
#define zsytrs_ zsytrs
#define zhetrs_ zhetrs
#define zhetri_ zhetri
#define dsysv_ dsysv
#define zsysv_ zsysv
#define dsygv_ dsygv
#define zhesv_ zhesv
#define dgels_ dgels
#define zgels_ zgels
#define dsyev_ dsyev
#define zheev_ zheev
#define dsyevx_ dsyevx
#define zheevx_ zheevx
#define dsyevd_ dsyevd
#define zheevd_ zheevd
#define dsyevr_ dsyevr
#define zheevr_ zheevr
#define ilaenv_ ilaenv
#define zhegv_ zhegv
#define dgesvd_ dgesvd
#define zgesvd_ zgesvd
#define dgesdd_ dgesdd
#define zgesdd_ zgesdd
#define dgeqrf_ dgeqrf
#define zgeqrf_ zgeqrf
#define dormqr_ dormqr
#define zunmqr_ zunmqr
#define dtrtrs_ dtrtrs
#define ztrtrs_ ztrtrs
#define dgbtrf_ dgbtrf
#define zgbtrf_ zgbtrf
#define dgbtrs_ dgbtrs
#define zgbtrs_ zgbtrs
#define dgbsv_  dgbsv
#define zgbsv_  zgbsv
#define dgtsv_  dgtsv
#define zgtsv_  zgtsv
#define dpbsv_  dpbsv
#define zpbsv_  zpbsv
#define dptsv_  dptsv
#define zptsv_  zptsv
#define dgttrf_ dgttrf
#define zgttrf_ zgttrf
#define dgttrs_ dgttrs
#define zgttrs_ zgttrs
#define dtrtri_ dtrtri
#define ztrtri_ ztrtri
#define dpbtrf_ dpbtrf
#define zpbtrf_ zpbtrf
#define dtbtrs_ dtbtrs
#define ztbtrs_ ztbtrs
#define dtbtrf_ dtbtrf
#define ztbtrf_ ztbtrf
#define dpttrf_ dpttrf
#define zpttrf_ zpttrf
#define dpbtrs_ dpbtrs
#define zpbtrs_ zpbtrs
#define dpttrs_ dpttrs
#define zpttrs_ zpttrs
#define dlacpy_ dlacpy
#define dgees_ dgees
#define zgees_ zgees
#define dgges_ dgges
#define zgges_ zgges

#endif
